@@ -1,28 +1,32 @@
-{-# LANGUAGE OverloadedStrings, ViewPatterns #-}
-module Util
-    ( relativeDirFromPieces
-    , defaultMkRedirect
-    , replace
-    , remove
-    , dropLastIfNull
-    ) where
+{-# LANGUAGE OverloadedStrings #-}
+{-# LANGUAGE ViewPatterns #-}
+
+module Util (
+    relativeDirFromPieces,
+    defaultMkRedirect,
+    replace,
+    remove,
+    dropLastIfNull,
+) where
 
-import WaiAppStatic.Types
-import qualified Data.Text as T
 import Data.ByteString (ByteString)
 import qualified Data.ByteString.Char8 as S8
+import qualified Data.Text as T
 import qualified Data.Text.Encoding as TE
+import WaiAppStatic.Types
 
 -- alist helper functions
 replace :: Eq a => a -> b -> [(a, b)] -> [(a, b)]
-replace k v [] = [(k,v)]
-replace k v (x:xs) | fst x == k = (k,v):xs
-                   | otherwise  = x:replace k v xs
+replace k v [] = [(k, v)]
+replace k v (x : xs)
+    | fst x == k = (k, v) : xs
+    | otherwise = x : replace k v xs
 
 remove :: Eq a => a -> [(a, b)] -> [(a, b)]
 remove _ [] = []
-remove k (x:xs) | fst x == k = xs
-                  | otherwise  = x:remove k xs
+remove k (x : xs)
+    | fst x == k = xs
+    | otherwise = x : remove k xs
 
 -- | Turn a list of pieces into a relative path to the root folder.
 relativeDirFromPieces :: Pieces -> T.Text
@@ -31,8 +35,10 @@ relativeDirFromPieces pieces = T.concat $ map (const "../") (drop 1 pieces) -- l
 -- | Construct redirects with relative paths.
 defaultMkRedirect :: Pieces -> ByteString -> S8.ByteString
 defaultMkRedirect pieces newPath
-    | S8.null newPath || S8.null relDir ||
-      S8.last relDir /= '/' || S8.head newPath /= '/' =
+    | S8.null newPath
+        || S8.null relDir
+        || S8.last relDir /= '/'
+        || S8.head newPath /= '/' =
         relDir `S8.append` newPath
     | otherwise = relDir `S8.append` S8.tail newPath
   where
