@@ -1,22 +1,27 @@
-{-# LANGUAGE TemplateHaskell, QuasiQuotes, OverloadedStrings, MagicHash, CPP #-}
-module WaiAppStatic.Storage.Embedded.TH(
-    Etag
-  , EmbeddableEntry(..)
-  , mkSettings
+{-# LANGUAGE CPP #-}
+{-# LANGUAGE MagicHash #-}
+{-# LANGUAGE OverloadedStrings #-}
+{-# LANGUAGE QuasiQuotes #-}
+{-# LANGUAGE TemplateHaskell #-}
+
+module WaiAppStatic.Storage.Embedded.TH (
+    Etag,
+    EmbeddableEntry (..),
+    mkSettings,
 ) where
 
-import Data.ByteString.Builder.Extra (byteStringInsert)
 import Codec.Compression.GZip (compress)
+import qualified Data.ByteString as B
+import Data.ByteString.Builder.Extra (byteStringInsert)
+import qualified Data.ByteString.Lazy as BL
 import Data.ByteString.Unsafe (unsafePackAddressLen)
 import Data.Either (lefts, rights)
-import GHC.Exts (Int(..))
+import GHC.Exts (Int (..))
 import Language.Haskell.TH
 import Network.Mime (MimeType, defaultMimeLookup)
 import System.IO.Unsafe (unsafeDupablePerformIO)
-import WaiAppStatic.Types
 import WaiAppStatic.Storage.Filesystem (defaultWebAppSettings)
-import qualified Data.ByteString as B
-import qualified Data.ByteString.Lazy as BL
+import WaiAppStatic.Types
 #if !MIN_VERSION_template_haskell(2, 8, 0)
 import qualified Data.ByteString.Char8 as B8
 import qualified Data.ByteString.Lazy.Char8 as BL8
@@ -33,35 +38,37 @@ import qualified Network.Wai as W
 type Etag = T.Text
 
 -- | Used at compile time to hold data about an entry to embed into the compiled executable.
-data EmbeddableEntry = EmbeddableEntry {
-    eLocation :: T.Text        -- ^ The location where this resource should be served from.  The
-                               --   location can contain forward slashes (/) to simulate directories,
-                               --   but must not end with a forward slash.
-  , eMimeType :: MimeType      -- ^ The mime type.
-  , eContent  :: Either (Etag, BL.ByteString) ExpQ
-                    -- ^ The content itself.  The content can be given as a tag and bytestring,
-                    --   in which case the content will be embedded directly into the execuatble.
-                    --   Alternatively, the content can be given as a template haskell expression
-                    --   returning @IO ('Etag', 'BL.ByteString')@ in which case this action will
-                    --   be executed on every request to reload the content (this is useful
-                    --   for a debugging mode).
-}
+data EmbeddableEntry = EmbeddableEntry
+    { eLocation :: T.Text
+    -- ^ The location where this resource should be served from.  The
+    --   location can contain forward slashes (/) to simulate directories,
+    --   but must not end with a forward slash.
+    , eMimeType :: MimeType
+    -- ^ The mime type.
+    , eContent :: Either (Etag, BL.ByteString) ExpQ
+    -- ^ The content itself.  The content can be given as a tag and bytestring,
+    --   in which case the content will be embedded directly into the execuatble.
+    --   Alternatively, the content can be given as a template haskell expression
+    --   returning @IO ('Etag', 'BL.ByteString')@ in which case this action will
+    --   be executed on every request to reload the content (this is useful
+    --   for a debugging mode).
+    }
 
 -- | This structure is used at runtime to hold the entry.
-data EmbeddedEntry = EmbeddedEntry {
-    embLocation   :: !T.Text
-  , embMime       :: !MimeType
-  , embEtag       :: !B.ByteString
-  , embCompressed :: !Bool
-  , embContent    :: !B.ByteString
-}
+data EmbeddedEntry = EmbeddedEntry
+    { embLocation :: !T.Text
+    , embMime :: !MimeType
+    , embEtag :: !B.ByteString
+    , embCompressed :: !Bool
+    , embContent :: !B.ByteString
+    }
 
 -- | This structure is used at runtime to hold the reload entries.
-data ReloadEntry = ReloadEntry {
-    reloadLocation :: !T.Text
-  , reloadMime     :: !MimeType
-  , reloadContent  :: IO (T.Text, BL.ByteString)
-}
+data ReloadEntry = ReloadEntry
+    { reloadLocation :: !T.Text
+    , reloadMime :: !MimeType
+    , reloadContent :: IO (T.Text, BL.ByteString)
+    }
 
 -- The use of unsafePackAddressLen is safe here because the length
 -- is correct and we will only be reading from the bytestring, never
@@ -102,90 +109,100 @@ bytestringLazyE b =
 -- | A template haskell expression which creates either an EmbeddedEntry or ReloadEntry.
 mkEntry :: EmbeddableEntry -> ExpQ
 mkEntry (EmbeddableEntry loc mime (Left (etag, ct))) =
-        [| Left $ EmbeddedEntry (T.pack $locE)
-                                $(bytestringE mime)
-                                $(bytestringE $ T.encodeUtf8 etag)
-                                (1 == I# $compressedE)
-                                $(bytestringLazyE ct')
+    [|
+        Left $
+            EmbeddedEntry
+                (T.pack $locE)
+                $(bytestringE mime)
+                $(bytestringE $ T.encodeUtf8 etag)
+                (1 == I# $compressedE)
+                $(bytestringLazyE ct')
         |]
-    where
-        locE = litE $ stringL $ T.unpack loc
-        (compressed, ct') = tryCompress mime ct
-        compressedE = litE $ intPrimL $ if compressed then 1 else 0
-
+  where
+    locE = litE $ stringL $ T.unpack loc
+    (compressed, ct') = tryCompress mime ct
+    compressedE = litE $ intPrimL $ if compressed then 1 else 0
 mkEntry (EmbeddableEntry loc mime (Right expr)) =
-        [| Right $ ReloadEntry (T.pack $locE)
-                               $(bytestringE mime)
-                               $expr
+    [|
+        Right $
+            ReloadEntry
+                (T.pack $locE)
+                $(bytestringE mime)
+                $expr
         |]
-    where
-        locE = litE $ stringL $ T.unpack loc
+  where
+    locE = litE $ stringL $ T.unpack loc
 
 -- | Converts an embedded entry to a file
 embeddedToFile :: EmbeddedEntry -> File
-embeddedToFile entry = File
-    { fileGetSize = fromIntegral $ B.length $ embContent entry
-    , fileToResponse = \s h ->
-        let h' = if embCompressed entry
-                    then h ++ [("Content-Encoding", "gzip")]
-                    else h
-         in W.responseBuilder s h' $ byteStringInsert $ embContent entry
-
-    -- Usually the fileName should just be the filename not the entire path,
-    -- but we need the whole path to make the lookup within lookupMime
-    -- possible.  lookupMime is provided only with the File and from that
-    -- we must find the mime type. Putting the path here is OK since
-    -- within staticApp the fileName is used for directory listings which
-    -- we have disabled.
-    , fileName = unsafeToPiece $ embLocation entry
-    , fileGetHash = return $ if B.null (embEtag entry)
-                                 then Nothing
-                                 else Just $ embEtag entry
-    , fileGetModified = Nothing
-    }
+embeddedToFile entry =
+    File
+        { fileGetSize = fromIntegral $ B.length $ embContent entry
+        , fileToResponse = \s h ->
+            let h' =
+                    if embCompressed entry
+                        then h ++ [("Content-Encoding", "gzip")]
+                        else h
+             in W.responseBuilder s h' $ byteStringInsert $ embContent entry
+        , -- Usually the fileName should just be the filename not the entire path,
+          -- but we need the whole path to make the lookup within lookupMime
+          -- possible.  lookupMime is provided only with the File and from that
+          -- we must find the mime type. Putting the path here is OK since
+          -- within staticApp the fileName is used for directory listings which
+          -- we have disabled.
+          fileName = unsafeToPiece $ embLocation entry
+        , fileGetHash =
+            return $
+                if B.null (embEtag entry)
+                    then Nothing
+                    else Just $ embEtag entry
+        , fileGetModified = Nothing
+        }
 
 -- | Converts a reload entry to a file
 reloadToFile :: ReloadEntry -> IO File
 reloadToFile entry = do
     (etag, ct) <- reloadContent entry
     let etag' = T.encodeUtf8 etag
-    return $ File
-        { fileGetSize = fromIntegral $ BL.length ct
-        , fileToResponse = \s h -> W.responseLBS s h ct
-        -- Similar to above the entire path needs to be in the fileName.
-        , fileName = unsafeToPiece $ reloadLocation entry
-        , fileGetHash = return $ if T.null etag then Nothing else Just etag'
-        , fileGetModified = Nothing
-        }
-
+    return $
+        File
+            { fileGetSize = fromIntegral $ BL.length ct
+            , fileToResponse = \s h -> W.responseLBS s h ct
+            , -- Similar to above the entire path needs to be in the fileName.
+              fileName = unsafeToPiece $ reloadLocation entry
+            , fileGetHash = return $ if T.null etag then Nothing else Just etag'
+            , fileGetModified = Nothing
+            }
 
 -- | Build a static settings based on a filemap.
 filemapToSettings :: M.HashMap T.Text (MimeType, IO File) -> StaticSettings
-filemapToSettings mfiles = (defaultWebAppSettings "")
-                              { ssLookupFile = lookupFile
-                              , ssGetMimeType = lookupMime
-                              }
-    where
-        piecesToFile p = T.intercalate "/" $ map fromPiece p
+filemapToSettings mfiles =
+    (defaultWebAppSettings "")
+        { ssLookupFile = lookupFile
+        , ssGetMimeType = lookupMime
+        }
+  where
+    piecesToFile p = T.intercalate "/" $ map fromPiece p
 
-        lookupFile [] = return LRNotFound
-        lookupFile p =
-            case M.lookup (piecesToFile p) mfiles of
-                Nothing -> return LRNotFound
-                Just (_,act) -> LRFile <$> act
+    lookupFile [] = return LRNotFound
+    lookupFile p =
+        case M.lookup (piecesToFile p) mfiles of
+            Nothing -> return LRNotFound
+            Just (_, act) -> LRFile <$> act
 
-        lookupMime (File { fileName = p }) =
-            case M.lookup (fromPiece p) mfiles of
-                Just (mime,_) -> return mime
-                Nothing -> return $ defaultMimeLookup $ fromPiece p
+    lookupMime (File{fileName = p}) =
+        case M.lookup (fromPiece p) mfiles of
+            Just (mime, _) -> return mime
+            Nothing -> return $ defaultMimeLookup $ fromPiece p
 
 -- | Create a 'StaticSettings' from a list of entries.  Executed at run time.
 entriesToSt :: [Either EmbeddedEntry ReloadEntry] -> StaticSettings
 entriesToSt entries = hmap `seq` filemapToSettings hmap
-    where
-        embFiles = [ (embLocation e, (embMime e, return $ embeddedToFile e)) | e <- lefts entries]
-        reloadFiles = [ (reloadLocation r, (reloadMime r, reloadToFile r)) | r <- rights entries]
-        hmap = M.fromList $ embFiles ++ reloadFiles
+  where
+    embFiles =
+        [(embLocation e, (embMime e, return $ embeddedToFile e)) | e <- lefts entries]
+    reloadFiles = [(reloadLocation r, (reloadMime r, reloadToFile r)) | r <- rights entries]
+    hmap = M.fromList $ embFiles ++ reloadFiles
 
 -- | Create a 'StaticSettings' at compile time that embeds resources directly into the compiled
 --   executable.  The embedded resources are precompressed (depending on mime type)
@@ -197,17 +214,17 @@ entriesToSt entries = hmap `seq` filemapToSettings hmap
 --
 -- > {-# LANGUAGE TemplateHaskell, QuasiQuotes, OverloadedStrings #-}
 -- > module A (mkEmbedded) where
--- > 
+-- >
 -- > import WaiAppStatic.Storage.Embedded
 -- > import Crypto.Hash.MD5 (hashlazy)
 -- > import qualified Data.ByteString.Lazy as BL
 -- > import qualified Data.ByteString.Base64 as B64
 -- > import qualified Data.Text as T
 -- > import qualified Data.Text.Encoding as T
--- > 
+-- >
 -- > hash :: BL.ByteString -> T.Text
 -- > hash = T.take 8 . T.decodeUtf8 . B64.encode . hashlazy
--- > 
+-- >
 -- > mkEmbedded :: IO [EmbeddableEntry]
 -- > mkEmbedded = do
 -- >     file <- BL.readFile "test.css"
@@ -216,13 +233,13 @@ entriesToSt entries = hmap `seq` filemapToSettings hmap
 -- >                 , eMimeType = "text/css"
 -- >                 , eContent  = Left (hash file, file)
 -- >                 }
--- > 
+-- >
 -- >     let reload = EmbeddableEntry {
 -- >                      eLocation = "anotherdir/test2.txt"
 -- >                    , eMimeType = "text/plain"
 -- >                    , eContent  = Right [| BL.readFile "test2.txt" >>= \c -> return (hash c, c) |]
 -- >                    }
--- > 
+-- >
 -- >     return [emb, reload]
 --
 -- The above @mkEmbedded@ will be executed at compile time.  It loads the contents of test.css and
@@ -241,37 +258,38 @@ entriesToSt entries = hmap `seq` filemapToSettings hmap
 --
 -- > {-# LANGUAGE TemplateHaskell #-}
 -- > module B where
--- > 
+-- >
 -- > import A
 -- > import Network.Wai (Application)
 -- > import Network.Wai.Application.Static (staticApp)
 -- > import WaiAppStatic.Storage.Embedded
 -- > import Network.Wai.Handler.Warp (run)
--- > 
+-- >
 -- > myApp :: Application
 -- > myApp = staticApp $(mkSettings mkEmbedded)
--- > 
+-- >
 -- > main :: IO ()
 -- > main = run 3000 myApp
 mkSettings :: IO [EmbeddableEntry] -> ExpQ
 mkSettings action = do
     entries <- runIO action
-    [| entriesToSt $(listE $ map mkEntry entries) |]
+    [|entriesToSt $(listE $ map mkEntry entries)|]
 
 shouldCompress :: MimeType -> Bool
 shouldCompress m = "text/" `B.isPrefixOf` m || m `elem` extra
-    where
-        extra = [ "application/json"
-                , "application/javascript"
-                , "application/ecmascript"
-                ]
+  where
+    extra =
+        [ "application/json"
+        , "application/javascript"
+        , "application/ecmascript"
+        ]
 
 -- | Only compress if the mime type is correct and the compressed text is actually shorter.
 tryCompress :: MimeType -> BL.ByteString -> (Bool, BL.ByteString)
 tryCompress mime ct
-        | shouldCompress mime = (c, ct')
-        | otherwise = (False, ct)
-    where
-        compressed = compress ct
-        c = BL.length compressed < BL.length ct
-        ct' = if c then compressed else ct
+    | shouldCompress mime = (c, ct')
+    | otherwise = (False, ct)
+  where
+    compressed = compress ct
+    c = BL.length compressed < BL.length ct
+    ct' = if c then compressed else ct
